// APP 全局事件处理
function appGlobal() {
	// 设置系统状态栏背景颜色
	// 文档 http://www.html5plus.org/doc/zh_cn/navigator.html#plus.navigator.setStatusBarBackground
	plus.navigator.setStatusBarBackground("#010915");
	// 设置系统状态栏样式
	// 文档 http://www.html5plus.org/doc/zh_cn/navigator.html#plus.navigator.setStatusBarStyle
	plus.navigator.setStatusBarStyle("light");
	// 锁定屏幕方向
	// 文档 http://www.html5plus.org/doc/zh_cn/device.html#plus.screen
	plus.screen.lockOrientation("portrait-primary");
	// 应用需要清理内存事件
	// 文档 http://www.html5plus.org/doc/zh_cn/events.html#plus.Events.%22trimmemory%22
	document.addEventListener("trimmemory", trimmemoryCallback, false);
	// 设备网络状态变化事件
	// 文档 http://www.html5plus.org/doc/zh_cn/events.html#plus.Events.%22netchange%22
	document.addEventListener("netchange", netchangeCallback, false);
	// 设备按钮按键事件
	// 文档 http://www.html5plus.org/doc/zh_cn/key.html	
	document.addEventListener("keypress", keyEventCallback(), false);
	// 取消浏览器的所有触摸事件
	document.addEventListener("touchstart", function() {
		return false;
	}, true);
};

// 应用需要清理内存事件
function trimmemoryCallback() {
	// 显示自动消失的提示消息
	plus.nativeUI.toast("已清理至最佳内存状态", {
		"duration": "long"
	});
};

// 设备网络状态变化事件处理
function netchangeCallback() {
	var nt = plus.networkinfo.getCurrentType();
	switch(nt) {
		case plus.networkinfo.CONNECTION_ETHERNET:
		case plus.networkinfo.CONNECTION_WIFI:
			// 显示自动消失的提示消息
			plus.nativeUI.toast("已连接至 Wi-Fi 网络", {
				"duration": "long"
			});
			break;
		case plus.networkinfo.CONNECTION_CELL2G:
		case plus.networkinfo.CONNECTION_CELL3G:
		case plus.networkinfo.CONNECTION_CELL4G:
			// 显示自动消失的提示消息
			plus.nativeUI.toast("已连接至蜂窝网络", {
				"duration": "long"
			});
			break;
		default:
			// 显示自动消失的提示消息
			plus.nativeUI.toast("网络连接不可用", {
				"duration": "long"
			});
			break;
	};
};

// 设备按钮按键事件
var Twv = null;

function keyEventCallback() {
	plus.key.addEventListener("backbutton", function() {
		Twv = plus.webview.getTopWebview();
		// 查询Webview窗口是否可后退
		// 文档 http://www.html5plus.org/doc/zh_cn/webview.html#plus.webview.WebviewObject.canBack
		Twv.canBack(
			function(event) {
				var canBack = event.canBack;
				console.log("是否可后退到上次加载的页面：" + canBack);
				if(canBack) {
					Twv.back();
				} else {
					switch(Twv) {
						case plus.webview.getLaunchWebview():
							// 仅 Android 设备支持						
							if(plus.os.name != "iOS") {
								// 弹出系统确认对话框
								plus.nativeUI.confirm("确认退出私家茶园？", function(event) {
									if(event.index == 0) {
										// 退出客户端程序
										plus.runtime.quit();
									};
								}, {
									"title": "警告",
									"buttons": ["确定", "取消"],
									"verticalAlign": "center"
								});
							} else {
								// 显示自动消失的提示消息
								plus.nativeUI.toast("退无可退", {
									"duration": "long"
								});
							};
							break;
						case plus.webview.getWebviewById("loginPage"):
							// 显示自动消失的提示消息
							plus.nativeUI.toast("请先登陆或注册", {
								"duration": "long"
							});
							break;
						default:
							Twv.close();
							break;
					};
				};
			}
		);
	}, false);
};